﻿using Microsoft.EntityFrameworkCore;
using SYBDContracts.BindingModels;
using SYBDContracts.SearchModels;
using SYBDContracts.StoragesContracts;
using SYBDContracts.ViewModels;
using SYBDDatabaseImplement.Models;

namespace SYBDDatabaseImplement.Implements
{
    public class OrderStorage : IOrderStorage
    {
        public OrderViewModel? Delete(OrderBindingModel model)
        {
            using var context = new SYBDDatabase();
            var element = context.order
                .Include(x => x.Auto)
                .Include(x => x.Client)
                .Include(x => x.Insurance)
                .Include(x => x.Worker)
                .FirstOrDefault(rec => rec.Id == model.Id);
            if (element != null)
            {
                context.order.Remove(element);
                context.SaveChanges();
                return element.GetViewModel;
            }
            return null;
        }

        public OrderViewModel? GetElement(OrderSearchModel model)
        {
            if (!model.Id.HasValue)
            {
                return null;
            }
            using var context = new SYBDDatabase();
            return context.order
                .Include(x => x.Auto)
                .Include(x => x.Client)
                .Include(x => x.Insurance)
                .Include(x => x.Worker)
                .FirstOrDefault(x => model.Id.HasValue && x.Id == model.Id)
                ?.GetViewModel;
        }

        public List<OrderViewModel> GetFilteredList(OrderSearchModel model)
        {
            if (!model.Id.HasValue)
            {
                return new();
            }
            using var context = new SYBDDatabase();
            return context.order
                .Include(x => x.Auto)
                .Include(x => x.Client)
                .Include(x => x.Insurance)
                .Include(x => x.Worker)
                    .Where(x => x.Id == model.Id)
                    .Select(x => x.GetViewModel)
                    .ToList();
        }

        public List<OrderViewModel> GetFullList()
        {
            using var context = new SYBDDatabase();
            return context.order
                .Include(x => x.Auto)
                .Include(x => x.Client)
                .Include(x => x.Insurance)
                .Include(x => x.Worker)
                    .Select(x => x.GetViewModel)
                    .ToList();
        }

        public OrderViewModel? Insert(OrderBindingModel model)
        {
            var newOrder = Order.Create(model);
            if (newOrder == null)
            {
                return null;
            }
            newOrder.Status = "В обработке";
            using var context = new SYBDDatabase();
            context.order.Add(newOrder);
            context.SaveChanges();
            return context.order
                .Include(x => x.Auto)
                .Include(x => x.Client)
                .Include(x => x.Insurance)
                .Include(x => x.Worker)
                .FirstOrDefault()
                ?.GetViewModel;
        }

        public OrderViewModel? Update(OrderBindingModel model)
        {
            using var context = new SYBDDatabase();
            var order = context.order
                .Include(x => x.Auto)
                .Include(x => x.Client)
                .Include(x => x.Insurance)
                .Include(x => x.Worker).FirstOrDefault(x => x.Id == model.Id);
            if (order == null)
            {
                return null;
            }
            order.Update(model);
            context.SaveChanges();
            return order.GetViewModel;
        }
    }
}