﻿using SYBDContracts.BindingModels;
using SYBDContracts.SearchModels;
using SYBDContracts.StoragesContracts;
using SYBDContracts.ViewModels;
using SYBDDatabaseImplement.Models;

namespace SYBDDatabaseImplement.Implements
{
    public class WorkerStorage : IWorkerStorage
    {
        public List<WorkerViewModel> GetFullList()
        {
            using var context = new SYBDDatabase();
            return context.worker
                    .Select(x => x.GetViewModel)
                    .ToList();
        }

        public List<WorkerViewModel> GetFilteredList(WorkerSearchModel model)
        {
            if (string.IsNullOrEmpty(model.Fullname))
            {
                return new();
            }
            using var context = new SYBDDatabase();
            return context.worker
                    .Where(x => x.Fullname.Contains(model.Fullname))
                    .Select(x => x.GetViewModel)
                    .ToList();
        }

        public WorkerViewModel? GetElement(WorkerSearchModel model)
        {
            if (string.IsNullOrEmpty(model.Fullname) && !model.Id.HasValue)
            {
                return null;
            }
            using var context = new SYBDDatabase();
            return context.worker
                    .FirstOrDefault(x => (!string.IsNullOrEmpty(model.Fullname) && x.Fullname == model.Fullname) ||
                                        (model.Id.HasValue && x.Id == model.Id))
                    ?.GetViewModel;
        }

        public WorkerViewModel? Insert(WorkerBindingModel model)
        {
            var newWorker = Worker.Create(model);
            if (newWorker == null)
            {
                return null;
            }
            using var context = new SYBDDatabase();
            context.worker.Add(newWorker);
            context.SaveChanges();
            return newWorker.GetViewModel;
        }

        public WorkerViewModel? Update(WorkerBindingModel model)
        {
            using var context = new SYBDDatabase();
            var component = context.worker.FirstOrDefault(x => x.Id == model.Id);
            if (component == null)
            {
                return null;
            }
            component.Update(model);
            context.SaveChanges();
            return component.GetViewModel;
        }

        public WorkerViewModel? Delete(WorkerBindingModel model)
        {
            using var context = new SYBDDatabase();
            var element = context.worker.FirstOrDefault(rec => rec.Id == model.Id);
            if (element != null)
            {
                context.worker.Remove(element);
                context.SaveChanges();
                return element.GetViewModel;
            }
            return null;
        }
    }
}