﻿using SYBDContracts.BindingModels;
using SYBDContracts.ViewModels;
using SYBDDataModels.Models;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace SYBDDatabaseImplement.Models
{
    public class Auto : IAutoModel
    {
        public int Id { get; private set; }

        [Required]
        public string Model { get; private set; } = string.Empty;

        [Required]
        public string StateNumber { get; private set; } = string.Empty;
        [ForeignKey("AutoId")]
        public virtual List<Order> Orders { get; set; } = new();
        public static Auto? Create(AutoBindingModel model)
        {
            if (model == null)
            {
                return null;
            }
            return new Auto()
            {
                Id = model.Id,
                Model = model.Model,
                StateNumber = model.StateNumber
            };
        }

        public static Auto Create(AutoViewModel model)
        {
            return new Auto
            {
                Id = model.Id,
                Model = model.Model,
                StateNumber = model.StateNumber
            };
        }

        public void Update(AutoBindingModel model)
        {
            if (model == null)
            {
                return;
            }
            Model = model.Model;
            StateNumber = model.StateNumber;
        }

        public AutoViewModel GetViewModel => new()
        {
            Id = Id,
            Model = Model,
            StateNumber = StateNumber
        };
    }
}