﻿using SYBDContracts.BindingModels;
using SYBDContracts.ViewModels;
using SYBDDataModels.Models;
using System.ComponentModel.DataAnnotations;

namespace SYBDDatabaseImplement.Models
{
    public class Order : IOrderModel
    {
        [Required]
        public int AutoId { get; set; }
        [Required]
        public int ClientId { get; set; }
        [Required]
        public int InsuranceId { get; set; }
        [Required]
        public int WorkerId { get; set; }

        [Required]
        public double Price { get; set; }
        [Required]
        public string Description { get; private set; } = string.Empty;
        [Required]
        public string Status { get; set; }
    
        public int Id { get; set; }

        public virtual Auto Auto { get; set; }
        public virtual Client Client { get; set; }
        public virtual Insurance Insurance { get; set; }
        public virtual Worker Worker { get; set; }

        public static Order? Create( OrderBindingModel? model)
        {
            if (model == null)
                return null;
            return new Order()
            {
                Id = model.Id,
                AutoId = model.AutoId,
                ClientId = model.ClientId,
                InsuranceId = model.InsuranceId,
                WorkerId = model.WorkerId,
                Price = model.Price,
                Description = model.Description,
                Status = model.Status,
            };
        }

        public void Update(OrderBindingModel? model)
        {
            if (model == null)
                return;
            Status = model.Status;
        }

        public OrderViewModel GetViewModel => new()
        {
            AutoId = AutoId,
            AutoModel = Auto.Model,
            ClientId = ClientId,
            ClientFullname = Client.Fullname,
            InsuranceId = InsuranceId,
            InsuranceName = Insurance.Name,
            WorkerId = WorkerId,
            WorkerFullname = Worker.Fullname,
            Price = Price,
            Description = Description,
            Status = Status,
            Id = Id,
        };
    }
}