﻿using SYBDContracts.BindingModels;
using SYBDContracts.BusinessLogicsContracts;
using SYBDContracts.SearchModels;
using Microsoft.Extensions.Logging;

namespace SYBDView
{
    public partial class FormAuto : Form
    {
        private readonly ILogger _logger;

        private readonly IAutoLogic _logic;

        private int? _id;
        public int Id { set { _id = value; } }

        public FormAuto(ILogger<FormAuto> logger, IAutoLogic logic)
        {
            InitializeComponent();
            _logger = logger;
            _logic = logic;
        }

        private void FormAuto_Load(object sender, EventArgs e)
        {
            if (_id.HasValue)
            {
                _logger.LogInformation("Загрузка автомобилей");
                try
                {
                    var view = _logic.ReadElement(new AutoSearchModel { Id = _id.Value });
                    if (view != null)
                    {
                        textBoxModel.Text = view.Model;
                        textBoxStateNumber.Text = view.StateNumber;
                    }
                }
                catch (Exception ex)
                {
                    _logger.LogError(ex, "Ошибка загрузки автомобиля");
                    MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }
        private void ButtonSave_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(textBoxModel.Text))
            {
                MessageBox.Show("Заполните модель", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (string.IsNullOrEmpty(textBoxStateNumber.Text))
            {
                MessageBox.Show("Заполните гос номер", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            _logger.LogInformation("Сохранение автомобиля");
            try
            {
                var model = new AutoBindingModel
                {
                    Id = _id ?? 0,
                    Model = textBoxModel.Text,
                    StateNumber = textBoxStateNumber.Text,
                };
                var operationResult = _id.HasValue ? _logic.Update(model) : _logic.Create(model);
                if (!operationResult)
                {
                    throw new Exception("Ошибка при сохранении. Дополнительная информация в логах.");
                }
                MessageBox.Show("Сохранение прошло успешно", "Сообщение", MessageBoxButtons.OK, MessageBoxIcon.Information);
                DialogResult = DialogResult.OK;
                Close();
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка сохранения автомобиля");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonCancel_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }
    }
}