﻿using SYBDContracts.BindingModels;
using SYBDContracts.BusinessLogicsContracts;
using SYBDContracts.SearchModels;
using Microsoft.Extensions.Logging;

namespace SYBDView
{
    public partial class FormInsurance : Form
    {
        public FormInsurance(ILogger<FormWorker> logger, IInsuranceLogic logic)
        {
            InitializeComponent();
            _logger = logger;
            _logic = logic;
        }
        private readonly ILogger _logger;

            private readonly IInsuranceLogic _logic;

            private int? _id;
            public int Id { set { _id = value; } }
            private void FormInsurances_Load(object sender, EventArgs e)
            {
                if (_id.HasValue)
                {
                    _logger.LogInformation("Загрузка страховой");
                    try
                    {
                        var view = _logic.ReadElement(new InsuranceSearchModel { Id = _id.Value });
                        if (view != null)
                        {
                            textBoxName.Text = view.Name;
                            textBoxAddress.Text = view.Address;
                            textBoxPhone.Text = view.Phone;
                        }
                    }
                    catch (Exception ex)
                    {
                        _logger.LogError(ex, "Ошибка загрузки страховой");
                        MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    }
                }
            }
            private void ButtonSave_Click(object sender, EventArgs e)
            {
                if (string.IsNullOrEmpty(textBoxName.Text))
                {
                    MessageBox.Show("Заполните название", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                if (string.IsNullOrEmpty(textBoxAddress.Text))
                {
                    MessageBox.Show("Заполните адрес", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                if (string.IsNullOrEmpty(textBoxPhone.Text))
                {
                    MessageBox.Show("Заполните телефон", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                _logger.LogInformation("Сохранение изделия");
                try
                {
                    var model = new InsuranceBindingModel
                    {
                        Id = _id ?? 0,
                        Name = textBoxName.Text,
                        Address = textBoxAddress.Text,
                        Phone = textBoxPhone.Text,
                    };
                    var operationResult = _id.HasValue ? _logic.Update(model) : _logic.Create(model);
                    if (!operationResult)
                    {
                        throw new Exception("Ошибка при сохранении. Дополнительная информация в логах.");
                    }
                    MessageBox.Show("Сохранение прошло успешно", "Сообщение", MessageBoxButtons.OK, MessageBoxIcon.Information);
                    DialogResult = DialogResult.OK;
                    Close();
                }
                catch (Exception ex)
                {
                    _logger.LogError(ex, "Ошибка сохранения изделия");
                    MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }

            private void ButtonCancel_Click(object sender, EventArgs e)
            {
                DialogResult = DialogResult.Cancel;
                Close();
            }
        }
    }
