﻿using SYBDContracts.BindingModels;
using SYBDContracts.BusinessLogicsContracts;
using SYBDContracts.SearchModels;
using Microsoft.Extensions.Logging;

namespace SYBDView
{
    public partial class FormWorker : Form
    {
        private readonly ILogger _logger;

        private readonly IWorkerLogic _logic;

        private int? _id;
        public int Id { set { _id = value; } }

        public FormWorker(ILogger<FormWorker> logger, IWorkerLogic logic)
        {
            InitializeComponent();
            _logger = logger;
            _logic = logic;
        }

        private void FormWork_Load(object sender, EventArgs e)
        {
            if (_id.HasValue)
            {
                _logger.LogInformation("Загрузка работников");
                try
                {
                    var view = _logic.ReadElement(new WorkerSearchModel { Id = _id.Value });
                    if (view != null)
                    {
                        textBoxFullname.Text = view.Fullname;
                        textBoxAddress.Text = view.Address;
                        textBoxSalary.Text = view.Salary.ToString();
                    }
                }
                catch (Exception ex)
                {
                    _logger.LogError(ex, "Ошибка загрузки работника");
                    MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }
        private void ButtonSave_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(textBoxFullname.Text))
            {
                MessageBox.Show("Заполните ФИО", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (string.IsNullOrEmpty(textBoxAddress.Text))
            {
                MessageBox.Show("Заполните адрес", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            if (string.IsNullOrEmpty(textBoxSalary.Text))
            {
                MessageBox.Show("Заполните зарплату", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            _logger.LogInformation("Сохранение изделия");
            try
            {
                var model = new WorkerBindingModel
                {
                    Id = _id ?? 0,
                    Fullname = textBoxFullname.Text,
                    Address = textBoxAddress.Text,
                    Salary = Convert.ToInt32(textBoxSalary.Text),
                };
                var operationResult = _id.HasValue ? _logic.Update(model) : _logic.Create(model);
                if (!operationResult)
                {
                    throw new Exception("Ошибка при сохранении. Дополнительная информация в логах.");
                }
                MessageBox.Show("Сохранение прошло успешно", "Сообщение", MessageBoxButtons.OK, MessageBoxIcon.Information);
                DialogResult = DialogResult.OK;
                Close();
            }
            catch (Exception ex)
            {
                _logger.LogError(ex, "Ошибка сохранения изделия");
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void ButtonCancel_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }
    }
}