using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
using NLog.Extensions.Logging;
using SYBDBusinessLogic.BusinessLogics;
using SYBDContracts.BusinessLogicsContracts;
using SYBDContracts.StoragesContracts;
using SYBDDatabaseImplement.Implements;

namespace SYBDView
{
    internal static class Program
    {
        private static ServiceProvider? _serviceProvider;
        public static ServiceProvider? ServiceProvider => _serviceProvider;

        /// <summary>
        ///  The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            // To customize application configuration such as set high DPI settings or default font,
            // see https://aka.ms/applicationconfiguration.
            ApplicationConfiguration.Initialize();
            var services = new ServiceCollection();
            ConfigureServices(services);
            _serviceProvider = services.BuildServiceProvider();
            Application.Run(_serviceProvider.GetRequiredService<FormMain>());
        }

        private static void ConfigureServices(ServiceCollection services)
        {
            services.AddLogging(option =>
            {
                option.SetMinimumLevel(LogLevel.Information);
                option.AddNLog("nlog.config");
            });
            services.AddTransient<IAutoStorage, AutoStorage>();
            services.AddTransient<IWorkerStorage, WorkerStorage>();
            services.AddTransient<IOrderStorage, OrderStorage>();
            services.AddTransient<IInsuranceStorage, InsuranceStorage>();
            services.AddTransient<IClientStorage, ClientStorage>();

            services.AddTransient<IAutoLogic, AutoLogic>();
            services.AddTransient<IOrderLogic, OrderLogic>();
            services.AddTransient<IWorkerLogic, WorkerLogic>();
            services.AddTransient<IInsuranceLogic, InsuranceLogic>();
            services.AddTransient<IClientLogic, ClientLogic>();

            services.AddTransient<FormMain>();
            services.AddTransient<FormAuto>();
            services.AddTransient<FormAutos>();
            services.AddTransient<FormCreateOrder>();
            services.AddTransient<FormWorker>();
            services.AddTransient<FormWorkers>();
            services.AddTransient<FormInsurance>();
            services.AddTransient<FormInsurances>();
            services.AddTransient<FormClients>();
            services.AddTransient<FormClient>();
        }
    }
}